#!/bin/bash

# $1 "on" or "parallel"
#   on: HEAD.
#   parallel: patched.

###############################################################################
# Steps to test:
# =========================
# 1. Execute `pub.sh` on publisher.
# 2. After the publication is created (see the output of publisher script: 'wait
#    for subscriber...' ), execute `sub.sh` on subscriber.
# 3. Wait for `pub.sh` to finish executing. The time of each run will be
#    output.
# 
# Example:
# To test 'parallel' mode, 10% of the data is sent.
# On publisher, execute `sh pub.sh parallel`.
# On subscriber, execute `sh sub.sh parallel 10`.
# 
# After all the tests, you need to stop the pg server manually. On publisher,
# execute `pg_ctl -D data_pub stop`. On subscriber, execute `pg_ctl -D data_sub
# stop`.
###############################################################################


path_parallel_apply=/home/postgres/install_pa/bin/
path_master=/home/postgres/install_head/bin/

loop=10

if [ "$1" = "on" ]; then
    path=$path_master
elif [ "$1" = "parallel" ]; then
    path=$path_parallel_apply
fi

pub_port=5432

${path}pg_ctl -D data_pub stop -m i
rm -rf data_pub pub.log

${path}initdb -D data_pub -U postgres

cat << EOF >> data_pub/postgresql.conf
listen_addresses = '*'
wal_level = logical
port = $pub_port
logical_decoding_work_mem = 64MB
shared_buffers = 8GB
checkpoint_timeout = 30min
max_wal_size = 20GB
min_wal_size = 10GB
autovacuum = off
EOF

cat << EOF >> data_pub/pg_hba.conf
host    all             all             all            trust
host    replication     all             all            trust
EOF


${path}pg_ctl -D data_pub start -l pub.log

${path}psql -d postgres -U postgres -p $pub_port -c "CREATE TABLE large_test (\
     id int primary key,\
     num1 bigint,\
     num2 double precision,\
     num3 double precision\
);"
${path}psql -d postgres -U postgres -p $pub_port -c "create publication pub_10 for table large_test where(id%100 < 10);"
${path}psql -d postgres -U postgres -p $pub_port -c "create publication pub_5 for table large_test where(id%100 < 5);"
${path}psql -d postgres -U postgres -p $pub_port -c "create publication pub_0 for table large_test where(id%100 < 0);"

echo "==============================================="
echo wait for subscriber...
sleep 20

echo set sync replication
echo synchronous_standby_names = \'any 1\(sub\)\' >> data_pub/postgresql.conf
${path}pg_ctl -D data_pub reload

rm res.txt
for i in `seq 1 $loop`; do
    ${path}psql -d postgres -U postgres -p $pub_port -f case_filter.sql | tee -a res.txt
done

grep '^Time' res.txt | awk '{print $4}' | sed 's/[(|)]//g'

